@@ -74,18 +74,23 @@ class Tpu(Base):
 
     def populate_class_labels(self):
         class_file_abs_path = self.options.get('object_labels')  
-        fp = open(class_file_abs_path)       
-        for row in fp:
-            # unpack the row and update the labels dictionary
-            (classID, label) = row.strip().split(" ", maxsplit=1)
-            self.classes[int(classID)] = label.strip()
-        fp.close()
+        if class_file_abs_path:
+            fp = open(class_file_abs_path)       
+            for row in fp:
+                # unpack the row and update the labels dictionary
+                (classID, label) = row.strip().split(" ", maxsplit=1)
+                self.classes[int(classID)] = label.strip()
+            fp.close()
+        else:
+            g.logger.Debug(1,'No label file provided for this model')
+            raise ValueError ('No label file provided for this model')
 
     def get_classes(self):
         return self.classes
 
     def load_model(self):
-        g.logger.Debug (1, '|--------- Loading TPU model from disk -------------|')
+        name = self.options.get('name') or 'TPU'
+        g.logger.Debug (1, '|--------- Loading "{}" model from disk -------------|'.format(name))
 
         #self.model = DetectionEngine(self.options.get('object_weights'))
         # Initialize the TF interpreter
@@ -97,7 +102,9 @@ class Tpu(Base):
             1,'perf: processor:{} TPU initialization (loading {} from disk) took: {}'
             .format(self.processor, self.options.get('object_weights'),diff_time))
         
+    
     def _nms(objects, threshold):
+    # not used - its already part of TPU core libs it seems
         # credit 
         # https://github.com/google-coral/pycoral/blob/master/examples/small_object_detection.py
 
@@ -195,8 +202,9 @@ class Tpu(Base):
                     int(round(obj.bbox.xmax)),
                     int(round(obj.bbox.ymax))
                 ])
-            labels.append(prefix+self.classes[obj.id])
+        
+            labels.append(prefix+self.classes.get(obj.id))
             conf.append(float(obj.score))
 
-        g.logger.Debug(3,'Coral returning: {},{},{}'.format(bbox,labels,conf))
+        g.logger.Debug(3,'Coral object returning: {},{},{}'.format(bbox,labels,conf))
         return bbox, labels, conf
