@@ -10,6 +10,8 @@ from pyzm.helpers.Media import MediaStream
 
 import time
 import requests
+import pyzm.helpers.globals as g
+
 
 # Class to handle Yolo based detection
 
@@ -18,24 +20,26 @@ import requests
 
 class Object(Base):
 
-    def __init__(self, options={}, logger=None):
+    def __init__(self, options={}):
 
-        Base.__init__(self,logger)
         self.model = None
         self.options = options
 
         if self.options.get('object_framework') == 'opencv':
             import pyzm.ml.yolo as yolo
-            self.model =  yolo.Yolo(options=options, logger=logger)
+            self.model =  yolo.Yolo(options=options)
             
 
         elif self.options.get('object_framework') == 'coral_edgetpu':
             import pyzm.ml.coral_edgetpu as tpu
-            self.model = tpu.Tpu(options=options, logger=logger)
+            self.model = tpu.Tpu(options=options)
 
         else:
             raise ValueError ('Invalid object_framework:{}'.format(self.options.get('object_framework')))
 
+    def get_options(self):
+        return self.options
+        
     def get_model(self):
             return self.model
 
@@ -52,11 +56,11 @@ class Object(Base):
     def detect(self,image=None):
         h,w = image.shape[:2]
         b,l,c = self.model.detect(image)
-        self.logger.Debug (3,'core model detection over, got {} objects. Now filtering'.format(len(b)))
+        g.logger.Debug (3,'core model detection over, got {} objects. Now filtering'.format(len(b)))
         # Apply various object filtering rules
         max_object_area = 0
         if self.options.get('max_detection_size'):
-                self.logger.Debug(3,'Max object size found to be: {}'.format(self.options.get('max_detection_size')))
+                g.logger.Debug(3,'Max object size found to be: {}'.format(self.options.get('max_detection_size')))
                 # Let's make sure its the right size
                 m = re.match('(\d*\.?\d*)(px|%)?$', self.options.get('max_detection_size'),
                             re.IGNORECASE)
@@ -64,9 +68,9 @@ class Object(Base):
                     max_object_area = float(m.group(1))
                     if m.group(2) == '%':
                         max_object_area = float(m.group(1))/100.0*(h * w)
-                        self.logger.Debug (2,'Converted {}% to {}'.format(m.group(1), max_object_area))
+                        g.logger.Debug (2,'Converted {}% to {}'.format(m.group(1), max_object_area))
                 else:
-                    self.logger.Error('max_object_area misformatted: {} - ignoring'.format(
+                    g.logger.Error('max_object_area misformatted: {} - ignoring'.format(
                         self.options.get('max_object_area')))
 
         boxes=[]
@@ -78,14 +82,14 @@ class Object(Base):
             if max_object_area:
                 object_area = abs((eX-sX)*(eY-sY))
                 if (object_area > max_object_area):
-                    self.logger.Debug (2,'Ignoring object:{}, as it\'s area: {}px exceeds max_object_area of {}px'.format(l[idx], object_area, max_object_area))
+                    g.logger.Debug (2,'Ignoring object:{}, as it\'s area: {}px exceeds max_object_area of {}px'.format(l[idx], object_area, max_object_area))
                     continue
             if c[idx] >= self.options.get('object_min_confidence'):
                 boxes.append([sX,sY,eX,eY])
                 labels.append(l[idx])
                 confidences.append(c[idx])
             else:
-                self.logger.Debug (2,'Ignoring {} {} as conf. level {} is lower than {}'.format(l[idx],box,c[idx],self.options.get('object_min_confidence')))
+                g.logger.Debug (2,'Ignoring {} {} as conf. level {} is lower than {}'.format(l[idx],box,c[idx],self.options.get('object_min_confidence')))
        
-        self.logger.Debug (2,'Returning filtered list of {} objects.'.format(len(boxes)))
+        g.logger.Debug (2,'Returning filtered list of {} objects.'.format(len(boxes)))
         return boxes,labels,confidences
